@@ -38,6 +38,10 @@ class DSHelper(BaseSqlHelper):
                 __import__("lesscode.db.elasticsearch.elasticsearch_helper", fromlist="ElasticsearchHelper"),
                 "ElasticsearchHelper")
             # self.db_helper = ElasticsearchHelper(self.pool)
+        elif self.dialect == "redis":
+            clazz = getattr(
+                __import__("lesscode.db.redis.redis_helper", fromlist="RedisHelper"),
+                "RedisHelper")
         if clazz:
             self.db_helper = clazz(self.pool)
 
