@@ -49,9 +49,15 @@ class InitConnectionPool:
                         pool = clazz(conn_info).create_pool()
                     elif conn_info.dialect == "elasticsearch":
                         # 获取包中用例的函数引用
-                        clazz = InitConnectionPool.getClass("lesscode.db.elasticsearch.elasticsearch_pool", fromlist="ElasticsearchPool")
+                        clazz = InitConnectionPool.getClass("lesscode.db.elasticsearch.elasticsearch_pool",
+                                                            fromlist="ElasticsearchPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
+                    # elif conn_info.dialect == "redis":
+                    #     # 获取包中用例的函数引用
+                    #     clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
+                    #     # 执行用例
+                    #     pool = await clazz(conn_info).create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
